@@ -15,7 +15,7 @@
 #define CMAKE_INSTALL_FULL_LIBDIR "/usr/lib"
 #define CMAKE_INSTALL_FULL_DATADIR "/usr/share/calamares"
 #define CMAKE_INSTALL_FULL_SYSCONFDIR "/etc"
-#define CMAKE_BUILD_TYPE "Release"
+#define CMAKE_BUILD_TYPE "Debug"
 
 /*
  * These are feature-settings that affect consumers of Calamares
