@@ -765,7 +765,7 @@ class DMsddm(DisplayManager):
         if os.path.isfile(sddm_conf_path):
             sddm_config.read(sddm_conf_path)
 
-        if 'Autologin' not in sddm_config:
+        if do_autologin and 'Autologin' not in sddm_config:
             sddm_config.add_section('Autologin')
 
         if do_autologin:
@@ -773,7 +773,7 @@ class DMsddm(DisplayManager):
         elif sddm_config.has_option('Autologin', 'User'):
             sddm_config.remove_option('Autologin', 'User')
 
-        if default_desktop_environment is not None:
+        if do_autologin and default_desktop_environment is not None:
             sddm_config.set(
                 'Autologin',
                 'Session',
